const { Model } = require('flitter-orm')

class APIRequest extends Model {
    static get services() {
        return [...super.services, 'output']
    }

    static get schema() {
        return {
            timestamp: { type: Date, default: () => new Date },
            request: {
                headers: Object,
                url: String,
                method: String,
                baseUrl: String,
                originalUrl: String,
                params: Object,
                query: Object,
                body: Object,
                session_id: String,
                cookies: Object,
                files: Object,
                // cookies:
            },
            is_auth: Boolean,
            user_id: String,
            additional_data: Object,
            response: {
                status_code: Number,
                message: String,
                data: Object,
            }
        }
    }

    static async log(req, { status_code, message, data }) {
        const log = new this({
            request: {
                headers: req.headers,
                url: req.url,
                method: req.method,
                baseUrl: req.baseUrl,
                originalUrl: req.originalUrl,
                params: req.params,
                query: req.query,
                body: req.body,
                session_id: req.sessionID,
                cookies: req.cookies,
                files: req.files,
            },
            is_auth: req.is_auth,
            user_id: req?.user?.id || req?.session?.auth?.user_id,
            additional_data: req?.additional_api_log_data || {},
            response: {
                status_code,
                message,
                data,
            },
        })

        await log.save()
        return log
    }
}

module.exports = exports = APIRequest
