/*
 * The libflitter Package
 * -------------------------------------------------------------
 * The libflitter package provides the core collection of units required
 * to get Flitter off the ground. These units rely on a particular folder
 * structure that is passed to the units. Each unit does one task and only
 * one task. This helps keep Flitter extensible, changeable, and relatively
 * easy to understand.
 */
const libflitter = {
    App: require('./app/FlitterApp'),
    Analyzer: require('./app/Analyzer'),
    FlitterApp: require('./app/FlitterApp'),
    AppUnit: require('./app/AppUnit'),

    CanonicalAccessUnit: require('./canon/CanonicalAccessUnit'),
    CanonicalUnit: require('./canon/CanonicalUnit'),

    ConfigUnit: require('./config/ConfigUnit'),

    Controller: require('./controller/Controller'),
    ControllerUnit: require('./controller/ControllerUnit'),

    Setting: require('./database/model/Setting.model'),
    DatabaseModelsUnit: require('./database/DatabaseModelsUnit'),
    DatabaseUnit: require('./database/DatabaseUnit'),

    ServerDirective: require('./directives/ServerDirective'),

    ErrorUnit: require('./errors/ErrorUnit'),
    FatalError: require('./errors/FatalError'),
    FlitterError: require('./errors/FlitterError'),
    HTTPError: require('./errors/HTTPError'),
    ImplementationError: require('./errors/ImplementationError'),
    RunLevelErrorHandler: require('./errors/RunLevelErrorHandler'),
    SoftError: require('./errors/SoftError'),
    StopError: require('./errors/StopError'),
    UnitRuntimeDependencyError: require('./errors/UnitRuntimeDependencyError'),
    UnitStaticDependencyError: require('./errors/UnitStaticDependencyError'),

    ExpressUnit: require('./express/ExpressUnit'),

    Middleware: require('./middleware/Middleware'),
    MiddlewareUnit: require('./middleware/MiddlewareUnit'),

    ResponseSystemMiddleware: require('./routing/ResponseSystemMiddleware'),
    RoutingUnit: require('./routing/RoutingUnit'),

    ServicesUnit: require('./services/ServicesUnit'),

    StaticUnit: require('./static/StaticUnit'),

    template_config: require('./templates/config'),
    template_controller: require('./templates/controller'),
    template_middleware: require('./templates/middleware'),
    template_model: require('./templates/model'),
    template_router: require('./templates/router'),
    template_service: require('./templates/service'),

    OutputService: require('./utility/services/Output.service'),
    UtilityUnit: require('./utility/UtilityUnit'),

    ViewEngineUnit: require('./views/ViewEngineUnit'),

    Unit: require('./Unit'),

    error_context: require('./errors/error_context.fn')
}

module.exports = exports = libflitter
